#
# spec file for package wayshot
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global rustflags '-Clink-arg=-Wl,-z,relro,-z,now'

Name:           wayshot
Version:        1.2.2
Release:        bp155.1.10
Summary:        Screenshot tool for wlroots based compositors
License:        (0BSD OR MIT OR Apache-2.0) AND (Apache-2.0 OR MIT) AND (Apache-2.0 OR MIT) AND (Apache-2.0 OR MIT OR Zlib) AND (MIT OR Unlicense) AND (Apache-2.0 OR Zlib OR MIT) AND BSD-3-Clause AND ISC AND MIT AND Zlib AND BSD-2-Clause
Group:          Productivity/Graphics/Other
URL:            https://github.com/waycrate/wayshot
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        cargo_config
%if 0%{?suse_version} >= 1500
BuildRequires:  cargo-packaging
%else
BuildRequires:  cargo
%endif

%description
A screenshot tool for wlroots based compositors implementing zwlr_screencopy_v1

%prep
%autosetup -a1
mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
%if 0%{?suse_version} >= 1500
RUSTFLAGS=%{rustflags} %{cargo_build}
%else
sed -i 's/2021/2018/g' Cargo.toml
RUSTFLAGS=%{rustflags} cargo build --offline --release
%endif

%install
%if 0%{?suse_version} >= 1500
RUSTFLAGS=%{rustflags} %{cargo_install}
%else
RUSTFLAGS=%{rustflags} cargo install --root=%{buildroot}%{_prefix} --path .
%endif

%files
%{_bindir}/wayshot
%license LICENSE
%doc README.md

%changelog
* Wed Sep 21 2022 socvirnyl.estela@gmail.com
- Update to version 1.2.2:
  * [bump] 1.2.2
  * [clippy] Remove PartialEq, Eq warning
  * [build.rs] Properly gzip the scdoc output
  * [update] ignore scdoc output files
  * [rustfmt] Fix formatting build.rs
  * [contrib/pkgbuild/bin] Update wayshot version
  * [bump] 1.2.1
  * [build.rs] Fix scdoc parent stdio inheritance
  * [contrib/pkgbuild/bin] Update wayshot version
  * [bump] 1.2.0
  * [chore] Bump dependencies
  * [BuildSystem]Don't depend on system shell for scd
  * [BuildSystem] Update install step
  * [contrib/pkgbuild/bin] Update makedeps
  * [contrib/pkgbuild] Fix man-page install paths
  * [docs/readme] Formattinge error
  * [Restructure] Move pkgbuilds into PKGBUILD
  * [contrib/pkgbuild/bin] Add man-page support
  * [contrib/pkgbuild/git]Add man-pages to git package
  * [BuildSystem] Improve man page installation
  * [contrib/pkgbuild/git] Add scdoc to makedeps
  * [build.rs] Binary existence check
  * [workflow] doc generation
  * [docs]Introduce scdoc generation in rust build sys
  * [chore] Cargo.lock
  * [contrib/pkgbuild/bin] update pkgbuild version
  * [backend.rs] PPM optimize performance
  * [docs/readme] color picker example
* Thu Aug  4 2022 William Brown <william.brown@suse.com>
- bsc#1182059 - CVE-2021-21299 - hyper request smuggling
* Thu Jul 21 2022 socvirnyl.estela@gmail.com
- Update to version 1.1.9:
  * [backend.rs] Add support for ppm rendering.
  * [bump] 1.1.8
  * [region-capture] out of bounds detection added
  * [update] add output dimension detection
  * [update] remove smithay dependency for faster builds
  * [push] .editorconfig
  * [update] memfd_create - add freebsd to target_os
  * [update] Readme.md
  * [chore] Cargo.lock
  * [update] replace xdg-output-handler with wl_output
* Sun May 29 2022 socvirnyl.estela@gmail.com
- Update to version 1.1.7~0:
  * [update] replace xdg-output-handler with wl_output
  * [update] nix deps bump and add repology to readme
  * [update] Sane error message on missing scrcpy.
  * [optimize dependencies] - Patch by jirutka
  * [update] Workflow.
  * [update] Bump dependencies.
  * [update] Readme
  * [update] Remove testing code.
  * [update] Fixes
  * [update] Add workflow.
- Use zstd compression :)
* Tue May 17 2022 socvirnyl.estela@gmail.com
- Update to version 1.1.5~1:
  * [update] Sane error message on missing scrcpy.
  * [optimize dependencies] - Patch by jirutka
  * [update] Workflow.
  * [update] Bump dependencies.
  * [update] Readme
  * [update] Remove testing code.
  * [update] Fixes
  * [update] Add workflow.
  * [update] fix readme
  * [update] Readme.
* Wed Mar 16 2022 socvirnyl.estela@gmail.com
- Update to version 1.1.5~0:
  * [update] Workflow.
  * [update] Bump dependencies.
  * [update] Readme
  * [update] Remove testing code.
  * [update] Fixes
  * [update] Add workflow.
  * [update] fix readme
  * [update] Readme.
  * [update]opensuse bin. Thanks to uncomfyhalomacro.
  * [update] shm.rs, bug fix
* Fri Mar 11 2022 socvirnyl.estela@gmail.com
- Update to version 1.1.5:
  * [update] Remove testing code.
  * [update] Fixes
  * [update] Add workflow.
  * [update] fix readme
  * [update] Readme.
  * [update]opensuse bin. Thanks to uncomfyhalomacro.
  * [update] shm.rs, bug fix
  * [update] Väinö Mäkelä, Replace unneeded roundtrip calls with dispatch
  * [bump] Version updates
  * [update] conflict with bin package
* Fri Mar 11 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Remove some reduntant Requires
- Remove not needed BuildRequires
* Fri Feb 25 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec
